Documentation
¶
Index ¶
- type AuthnService
- type AuthnService_Expecter
- type AuthnService_GetPrincipal_Call
- func (_c *AuthnService_GetPrincipal_Call) Return(_a0 authenticate.Principal, _a1 error) *AuthnService_GetPrincipal_Call
- func (_c *AuthnService_GetPrincipal_Call) Run(run func(ctx context.Context, via ...authenticate.ClientAssertion)) *AuthnService_GetPrincipal_Call
- func (_c *AuthnService_GetPrincipal_Call) RunAndReturn(...) *AuthnService_GetPrincipal_Call
- type ConfigRepository
- type ConfigRepository_Expecter
- type ConfigRepository_GetAll_Call
- func (_c *ConfigRepository_GetAll_Call) Return(_a0 []resource.YAML, _a1 error) *ConfigRepository_GetAll_Call
- func (_c *ConfigRepository_GetAll_Call) Run(run func(ctx context.Context)) *ConfigRepository_GetAll_Call
- func (_c *ConfigRepository_GetAll_Call) RunAndReturn(run func(context.Context) ([]resource.YAML, error)) *ConfigRepository_GetAll_Call
- type OrgService
- type OrgService_Expecter
- type OrgService_Get_Call
- func (_c *OrgService_Get_Call) Return(_a0 organization.Organization, _a1 error) *OrgService_Get_Call
- func (_c *OrgService_Get_Call) Run(run func(ctx context.Context, idOrName string)) *OrgService_Get_Call
- func (_c *OrgService_Get_Call) RunAndReturn(run func(context.Context, string) (organization.Organization, error)) *OrgService_Get_Call
- type PATService
- type PATService_Expecter
- type PATService_GetByID_Call
- func (_c *PATService_GetByID_Call) Return(_a0 models.PAT, _a1 error) *PATService_GetByID_Call
- func (_c *PATService_GetByID_Call) Run(run func(ctx context.Context, id string)) *PATService_GetByID_Call
- func (_c *PATService_GetByID_Call) RunAndReturn(run func(context.Context, string) (models.PAT, error)) *PATService_GetByID_Call
- type ProjectService
- type ProjectService_Expecter
- type ProjectService_Get_Call
- func (_c *ProjectService_Get_Call) Return(_a0 project.Project, _a1 error) *ProjectService_Get_Call
- func (_c *ProjectService_Get_Call) Run(run func(ctx context.Context, idOrName string)) *ProjectService_Get_Call
- func (_c *ProjectService_Get_Call) RunAndReturn(run func(context.Context, string) (project.Project, error)) *ProjectService_Get_Call
- type RelationService
- func (_m *RelationService) BatchCheckPermission(ctx context.Context, relations []relation.Relation) ([]relation.CheckPair, error)
- func (_m *RelationService) CheckPermission(ctx context.Context, rel relation.Relation) (bool, error)
- func (_m *RelationService) Create(ctx context.Context, rel relation.Relation) (relation.Relation, error)
- func (_m *RelationService) Delete(ctx context.Context, rel relation.Relation) error
- func (_m *RelationService) EXPECT() *RelationService_Expecter
- type RelationService_BatchCheckPermission_Call
- func (_c *RelationService_BatchCheckPermission_Call) Return(_a0 []relation.CheckPair, _a1 error) *RelationService_BatchCheckPermission_Call
- func (_c *RelationService_BatchCheckPermission_Call) Run(run func(ctx context.Context, relations []relation.Relation)) *RelationService_BatchCheckPermission_Call
- func (_c *RelationService_BatchCheckPermission_Call) RunAndReturn(run func(context.Context, []relation.Relation) ([]relation.CheckPair, error)) *RelationService_BatchCheckPermission_Call
- type RelationService_CheckPermission_Call
- func (_c *RelationService_CheckPermission_Call) Return(_a0 bool, _a1 error) *RelationService_CheckPermission_Call
- func (_c *RelationService_CheckPermission_Call) Run(run func(ctx context.Context, rel relation.Relation)) *RelationService_CheckPermission_Call
- func (_c *RelationService_CheckPermission_Call) RunAndReturn(run func(context.Context, relation.Relation) (bool, error)) *RelationService_CheckPermission_Call
- type RelationService_Create_Call
- func (_c *RelationService_Create_Call) Return(_a0 relation.Relation, _a1 error) *RelationService_Create_Call
- func (_c *RelationService_Create_Call) Run(run func(ctx context.Context, rel relation.Relation)) *RelationService_Create_Call
- func (_c *RelationService_Create_Call) RunAndReturn(run func(context.Context, relation.Relation) (relation.Relation, error)) *RelationService_Create_Call
- type RelationService_Delete_Call
- func (_c *RelationService_Delete_Call) Return(_a0 error) *RelationService_Delete_Call
- func (_c *RelationService_Delete_Call) Run(run func(ctx context.Context, rel relation.Relation)) *RelationService_Delete_Call
- func (_c *RelationService_Delete_Call) RunAndReturn(run func(context.Context, relation.Relation) error) *RelationService_Delete_Call
- type RelationService_Expecter
- func (_e *RelationService_Expecter) BatchCheckPermission(ctx interface{}, relations interface{}) *RelationService_BatchCheckPermission_Call
- func (_e *RelationService_Expecter) CheckPermission(ctx interface{}, rel interface{}) *RelationService_CheckPermission_Call
- func (_e *RelationService_Expecter) Create(ctx interface{}, rel interface{}) *RelationService_Create_Call
- func (_e *RelationService_Expecter) Delete(ctx interface{}, rel interface{}) *RelationService_Delete_Call
- type Repository
- func (_m *Repository) Create(ctx context.Context, _a1 resource.Resource) (resource.Resource, error)
- func (_m *Repository) Delete(ctx context.Context, id string) error
- func (_m *Repository) EXPECT() *Repository_Expecter
- func (_m *Repository) GetByID(ctx context.Context, id string) (resource.Resource, error)
- func (_m *Repository) GetByURN(ctx context.Context, urn string) (resource.Resource, error)
- func (_m *Repository) List(ctx context.Context, flt resource.Filter) ([]resource.Resource, error)
- func (_m *Repository) Update(ctx context.Context, _a1 resource.Resource) (resource.Resource, error)
- type Repository_Create_Call
- func (_c *Repository_Create_Call) Return(_a0 resource.Resource, _a1 error) *Repository_Create_Call
- func (_c *Repository_Create_Call) Run(run func(ctx context.Context, _a1 resource.Resource)) *Repository_Create_Call
- func (_c *Repository_Create_Call) RunAndReturn(run func(context.Context, resource.Resource) (resource.Resource, error)) *Repository_Create_Call
- type Repository_Delete_Call
- type Repository_Expecter
- func (_e *Repository_Expecter) Create(ctx interface{}, _a1 interface{}) *Repository_Create_Call
- func (_e *Repository_Expecter) Delete(ctx interface{}, id interface{}) *Repository_Delete_Call
- func (_e *Repository_Expecter) GetByID(ctx interface{}, id interface{}) *Repository_GetByID_Call
- func (_e *Repository_Expecter) GetByURN(ctx interface{}, urn interface{}) *Repository_GetByURN_Call
- func (_e *Repository_Expecter) List(ctx interface{}, flt interface{}) *Repository_List_Call
- func (_e *Repository_Expecter) Update(ctx interface{}, _a1 interface{}) *Repository_Update_Call
- type Repository_GetByID_Call
- func (_c *Repository_GetByID_Call) Return(_a0 resource.Resource, _a1 error) *Repository_GetByID_Call
- func (_c *Repository_GetByID_Call) Run(run func(ctx context.Context, id string)) *Repository_GetByID_Call
- func (_c *Repository_GetByID_Call) RunAndReturn(run func(context.Context, string) (resource.Resource, error)) *Repository_GetByID_Call
- type Repository_GetByURN_Call
- func (_c *Repository_GetByURN_Call) Return(_a0 resource.Resource, _a1 error) *Repository_GetByURN_Call
- func (_c *Repository_GetByURN_Call) Run(run func(ctx context.Context, urn string)) *Repository_GetByURN_Call
- func (_c *Repository_GetByURN_Call) RunAndReturn(run func(context.Context, string) (resource.Resource, error)) *Repository_GetByURN_Call
- type Repository_List_Call
- func (_c *Repository_List_Call) Return(_a0 []resource.Resource, _a1 error) *Repository_List_Call
- func (_c *Repository_List_Call) Run(run func(ctx context.Context, flt resource.Filter)) *Repository_List_Call
- func (_c *Repository_List_Call) RunAndReturn(run func(context.Context, resource.Filter) ([]resource.Resource, error)) *Repository_List_Call
- type Repository_Update_Call
- func (_c *Repository_Update_Call) Return(_a0 resource.Resource, _a1 error) *Repository_Update_Call
- func (_c *Repository_Update_Call) Run(run func(ctx context.Context, _a1 resource.Resource)) *Repository_Update_Call
- func (_c *Repository_Update_Call) RunAndReturn(run func(context.Context, resource.Resource) (resource.Resource, error)) *Repository_Update_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AuthnService ¶
AuthnService is an autogenerated mock type for the AuthnService type
func NewAuthnService ¶
func NewAuthnService(t interface {
mock.TestingT
Cleanup(func())
}) *AuthnService
NewAuthnService creates a new instance of AuthnService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*AuthnService) EXPECT ¶
func (_m *AuthnService) EXPECT() *AuthnService_Expecter
func (*AuthnService) GetPrincipal ¶
func (_m *AuthnService) GetPrincipal(ctx context.Context, via ...authenticate.ClientAssertion) (authenticate.Principal, error)
GetPrincipal provides a mock function with given fields: ctx, via
type AuthnService_Expecter ¶
type AuthnService_Expecter struct {
// contains filtered or unexported fields
}
func (*AuthnService_Expecter) GetPrincipal ¶
func (_e *AuthnService_Expecter) GetPrincipal(ctx interface{}, via ...interface{}) *AuthnService_GetPrincipal_Call
GetPrincipal is a helper method to define mock.On call
- ctx context.Context
- via ...authenticate.ClientAssertion
type AuthnService_GetPrincipal_Call ¶
AuthnService_GetPrincipal_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetPrincipal'
func (*AuthnService_GetPrincipal_Call) Return ¶
func (_c *AuthnService_GetPrincipal_Call) Return(_a0 authenticate.Principal, _a1 error) *AuthnService_GetPrincipal_Call
func (*AuthnService_GetPrincipal_Call) Run ¶
func (_c *AuthnService_GetPrincipal_Call) Run(run func(ctx context.Context, via ...authenticate.ClientAssertion)) *AuthnService_GetPrincipal_Call
func (*AuthnService_GetPrincipal_Call) RunAndReturn ¶
func (_c *AuthnService_GetPrincipal_Call) RunAndReturn(run func(context.Context, ...authenticate.ClientAssertion) (authenticate.Principal, error)) *AuthnService_GetPrincipal_Call
type ConfigRepository ¶
ConfigRepository is an autogenerated mock type for the ConfigRepository type
func NewConfigRepository ¶
func NewConfigRepository(t interface {
mock.TestingT
Cleanup(func())
}) *ConfigRepository
NewConfigRepository creates a new instance of ConfigRepository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ConfigRepository) EXPECT ¶
func (_m *ConfigRepository) EXPECT() *ConfigRepository_Expecter
type ConfigRepository_Expecter ¶
type ConfigRepository_Expecter struct {
// contains filtered or unexported fields
}
func (*ConfigRepository_Expecter) GetAll ¶
func (_e *ConfigRepository_Expecter) GetAll(ctx interface{}) *ConfigRepository_GetAll_Call
GetAll is a helper method to define mock.On call
- ctx context.Context
type ConfigRepository_GetAll_Call ¶
ConfigRepository_GetAll_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetAll'
func (*ConfigRepository_GetAll_Call) Return ¶
func (_c *ConfigRepository_GetAll_Call) Return(_a0 []resource.YAML, _a1 error) *ConfigRepository_GetAll_Call
func (*ConfigRepository_GetAll_Call) Run ¶
func (_c *ConfigRepository_GetAll_Call) Run(run func(ctx context.Context)) *ConfigRepository_GetAll_Call
func (*ConfigRepository_GetAll_Call) RunAndReturn ¶
func (_c *ConfigRepository_GetAll_Call) RunAndReturn(run func(context.Context) ([]resource.YAML, error)) *ConfigRepository_GetAll_Call
type OrgService ¶
OrgService is an autogenerated mock type for the OrgService type
func NewOrgService ¶
func NewOrgService(t interface {
mock.TestingT
Cleanup(func())
}) *OrgService
NewOrgService creates a new instance of OrgService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*OrgService) EXPECT ¶
func (_m *OrgService) EXPECT() *OrgService_Expecter
func (*OrgService) Get ¶
func (_m *OrgService) Get(ctx context.Context, idOrName string) (organization.Organization, error)
Get provides a mock function with given fields: ctx, idOrName
type OrgService_Expecter ¶
type OrgService_Expecter struct {
// contains filtered or unexported fields
}
func (*OrgService_Expecter) Get ¶
func (_e *OrgService_Expecter) Get(ctx interface{}, idOrName interface{}) *OrgService_Get_Call
Get is a helper method to define mock.On call
- ctx context.Context
- idOrName string
type OrgService_Get_Call ¶
OrgService_Get_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Get'
func (*OrgService_Get_Call) Return ¶
func (_c *OrgService_Get_Call) Return(_a0 organization.Organization, _a1 error) *OrgService_Get_Call
func (*OrgService_Get_Call) Run ¶
func (_c *OrgService_Get_Call) Run(run func(ctx context.Context, idOrName string)) *OrgService_Get_Call
func (*OrgService_Get_Call) RunAndReturn ¶
func (_c *OrgService_Get_Call) RunAndReturn(run func(context.Context, string) (organization.Organization, error)) *OrgService_Get_Call
type PATService ¶
PATService is an autogenerated mock type for the PATService type
func NewPATService ¶
func NewPATService(t interface {
mock.TestingT
Cleanup(func())
}) *PATService
NewPATService creates a new instance of PATService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*PATService) EXPECT ¶
func (_m *PATService) EXPECT() *PATService_Expecter
type PATService_Expecter ¶
type PATService_Expecter struct {
// contains filtered or unexported fields
}
func (*PATService_Expecter) GetByID ¶
func (_e *PATService_Expecter) GetByID(ctx interface{}, id interface{}) *PATService_GetByID_Call
GetByID is a helper method to define mock.On call
- ctx context.Context
- id string
type PATService_GetByID_Call ¶
PATService_GetByID_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetByID'
func (*PATService_GetByID_Call) Return ¶
func (_c *PATService_GetByID_Call) Return(_a0 models.PAT, _a1 error) *PATService_GetByID_Call
func (*PATService_GetByID_Call) Run ¶
func (_c *PATService_GetByID_Call) Run(run func(ctx context.Context, id string)) *PATService_GetByID_Call
func (*PATService_GetByID_Call) RunAndReturn ¶
func (_c *PATService_GetByID_Call) RunAndReturn(run func(context.Context, string) (models.PAT, error)) *PATService_GetByID_Call
type ProjectService ¶
ProjectService is an autogenerated mock type for the ProjectService type
func NewProjectService ¶
func NewProjectService(t interface {
mock.TestingT
Cleanup(func())
}) *ProjectService
NewProjectService creates a new instance of ProjectService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*ProjectService) EXPECT ¶
func (_m *ProjectService) EXPECT() *ProjectService_Expecter
type ProjectService_Expecter ¶
type ProjectService_Expecter struct {
// contains filtered or unexported fields
}
func (*ProjectService_Expecter) Get ¶
func (_e *ProjectService_Expecter) Get(ctx interface{}, idOrName interface{}) *ProjectService_Get_Call
Get is a helper method to define mock.On call
- ctx context.Context
- idOrName string
type ProjectService_Get_Call ¶
ProjectService_Get_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Get'
func (*ProjectService_Get_Call) Return ¶
func (_c *ProjectService_Get_Call) Return(_a0 project.Project, _a1 error) *ProjectService_Get_Call
func (*ProjectService_Get_Call) Run ¶
func (_c *ProjectService_Get_Call) Run(run func(ctx context.Context, idOrName string)) *ProjectService_Get_Call
func (*ProjectService_Get_Call) RunAndReturn ¶
func (_c *ProjectService_Get_Call) RunAndReturn(run func(context.Context, string) (project.Project, error)) *ProjectService_Get_Call
type RelationService ¶
RelationService is an autogenerated mock type for the RelationService type
func NewRelationService ¶
func NewRelationService(t interface {
mock.TestingT
Cleanup(func())
}) *RelationService
NewRelationService creates a new instance of RelationService. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*RelationService) BatchCheckPermission ¶
func (_m *RelationService) BatchCheckPermission(ctx context.Context, relations []relation.Relation) ([]relation.CheckPair, error)
BatchCheckPermission provides a mock function with given fields: ctx, relations
func (*RelationService) CheckPermission ¶
func (_m *RelationService) CheckPermission(ctx context.Context, rel relation.Relation) (bool, error)
CheckPermission provides a mock function with given fields: ctx, rel
func (*RelationService) Create ¶
func (_m *RelationService) Create(ctx context.Context, rel relation.Relation) (relation.Relation, error)
Create provides a mock function with given fields: ctx, rel
func (*RelationService) EXPECT ¶
func (_m *RelationService) EXPECT() *RelationService_Expecter
type RelationService_BatchCheckPermission_Call ¶
RelationService_BatchCheckPermission_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'BatchCheckPermission'
func (*RelationService_BatchCheckPermission_Call) Return ¶
func (_c *RelationService_BatchCheckPermission_Call) Return(_a0 []relation.CheckPair, _a1 error) *RelationService_BatchCheckPermission_Call
func (*RelationService_BatchCheckPermission_Call) Run ¶
func (_c *RelationService_BatchCheckPermission_Call) Run(run func(ctx context.Context, relations []relation.Relation)) *RelationService_BatchCheckPermission_Call
func (*RelationService_BatchCheckPermission_Call) RunAndReturn ¶
func (_c *RelationService_BatchCheckPermission_Call) RunAndReturn(run func(context.Context, []relation.Relation) ([]relation.CheckPair, error)) *RelationService_BatchCheckPermission_Call
type RelationService_CheckPermission_Call ¶
RelationService_CheckPermission_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'CheckPermission'
func (*RelationService_CheckPermission_Call) Return ¶
func (_c *RelationService_CheckPermission_Call) Return(_a0 bool, _a1 error) *RelationService_CheckPermission_Call
func (*RelationService_CheckPermission_Call) Run ¶
func (_c *RelationService_CheckPermission_Call) Run(run func(ctx context.Context, rel relation.Relation)) *RelationService_CheckPermission_Call
func (*RelationService_CheckPermission_Call) RunAndReturn ¶
func (_c *RelationService_CheckPermission_Call) RunAndReturn(run func(context.Context, relation.Relation) (bool, error)) *RelationService_CheckPermission_Call
type RelationService_Create_Call ¶
RelationService_Create_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Create'
func (*RelationService_Create_Call) Return ¶
func (_c *RelationService_Create_Call) Return(_a0 relation.Relation, _a1 error) *RelationService_Create_Call
func (*RelationService_Create_Call) Run ¶
func (_c *RelationService_Create_Call) Run(run func(ctx context.Context, rel relation.Relation)) *RelationService_Create_Call
func (*RelationService_Create_Call) RunAndReturn ¶
func (_c *RelationService_Create_Call) RunAndReturn(run func(context.Context, relation.Relation) (relation.Relation, error)) *RelationService_Create_Call
type RelationService_Delete_Call ¶
RelationService_Delete_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Delete'
func (*RelationService_Delete_Call) Return ¶
func (_c *RelationService_Delete_Call) Return(_a0 error) *RelationService_Delete_Call
func (*RelationService_Delete_Call) Run ¶
func (_c *RelationService_Delete_Call) Run(run func(ctx context.Context, rel relation.Relation)) *RelationService_Delete_Call
func (*RelationService_Delete_Call) RunAndReturn ¶
func (_c *RelationService_Delete_Call) RunAndReturn(run func(context.Context, relation.Relation) error) *RelationService_Delete_Call
type RelationService_Expecter ¶
type RelationService_Expecter struct {
// contains filtered or unexported fields
}
func (*RelationService_Expecter) BatchCheckPermission ¶
func (_e *RelationService_Expecter) BatchCheckPermission(ctx interface{}, relations interface{}) *RelationService_BatchCheckPermission_Call
BatchCheckPermission is a helper method to define mock.On call
- ctx context.Context
- relations []relation.Relation
func (*RelationService_Expecter) CheckPermission ¶
func (_e *RelationService_Expecter) CheckPermission(ctx interface{}, rel interface{}) *RelationService_CheckPermission_Call
CheckPermission is a helper method to define mock.On call
- ctx context.Context
- rel relation.Relation
func (*RelationService_Expecter) Create ¶
func (_e *RelationService_Expecter) Create(ctx interface{}, rel interface{}) *RelationService_Create_Call
Create is a helper method to define mock.On call
- ctx context.Context
- rel relation.Relation
func (*RelationService_Expecter) Delete ¶
func (_e *RelationService_Expecter) Delete(ctx interface{}, rel interface{}) *RelationService_Delete_Call
Delete is a helper method to define mock.On call
- ctx context.Context
- rel relation.Relation
type Repository ¶
Repository is an autogenerated mock type for the Repository type
func NewRepository ¶
func NewRepository(t interface {
mock.TestingT
Cleanup(func())
}) *Repository
NewRepository creates a new instance of Repository. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*Repository) Delete ¶
func (_m *Repository) Delete(ctx context.Context, id string) error
Delete provides a mock function with given fields: ctx, id
func (*Repository) EXPECT ¶
func (_m *Repository) EXPECT() *Repository_Expecter
type Repository_Create_Call ¶
Repository_Create_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Create'
func (*Repository_Create_Call) Return ¶
func (_c *Repository_Create_Call) Return(_a0 resource.Resource, _a1 error) *Repository_Create_Call
func (*Repository_Create_Call) Run ¶
func (_c *Repository_Create_Call) Run(run func(ctx context.Context, _a1 resource.Resource)) *Repository_Create_Call
func (*Repository_Create_Call) RunAndReturn ¶
func (_c *Repository_Create_Call) RunAndReturn(run func(context.Context, resource.Resource) (resource.Resource, error)) *Repository_Create_Call
type Repository_Delete_Call ¶
Repository_Delete_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Delete'
func (*Repository_Delete_Call) Return ¶
func (_c *Repository_Delete_Call) Return(_a0 error) *Repository_Delete_Call
func (*Repository_Delete_Call) Run ¶
func (_c *Repository_Delete_Call) Run(run func(ctx context.Context, id string)) *Repository_Delete_Call
func (*Repository_Delete_Call) RunAndReturn ¶
func (_c *Repository_Delete_Call) RunAndReturn(run func(context.Context, string) error) *Repository_Delete_Call
type Repository_Expecter ¶
type Repository_Expecter struct {
// contains filtered or unexported fields
}
func (*Repository_Expecter) Create ¶
func (_e *Repository_Expecter) Create(ctx interface{}, _a1 interface{}) *Repository_Create_Call
Create is a helper method to define mock.On call
- ctx context.Context
- _a1 resource.Resource
func (*Repository_Expecter) Delete ¶
func (_e *Repository_Expecter) Delete(ctx interface{}, id interface{}) *Repository_Delete_Call
Delete is a helper method to define mock.On call
- ctx context.Context
- id string
func (*Repository_Expecter) GetByID ¶
func (_e *Repository_Expecter) GetByID(ctx interface{}, id interface{}) *Repository_GetByID_Call
GetByID is a helper method to define mock.On call
- ctx context.Context
- id string
func (*Repository_Expecter) GetByURN ¶
func (_e *Repository_Expecter) GetByURN(ctx interface{}, urn interface{}) *Repository_GetByURN_Call
GetByURN is a helper method to define mock.On call
- ctx context.Context
- urn string
func (*Repository_Expecter) List ¶
func (_e *Repository_Expecter) List(ctx interface{}, flt interface{}) *Repository_List_Call
List is a helper method to define mock.On call
- ctx context.Context
- flt resource.Filter
func (*Repository_Expecter) Update ¶
func (_e *Repository_Expecter) Update(ctx interface{}, _a1 interface{}) *Repository_Update_Call
Update is a helper method to define mock.On call
- ctx context.Context
- _a1 resource.Resource
type Repository_GetByID_Call ¶
Repository_GetByID_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetByID'
func (*Repository_GetByID_Call) Return ¶
func (_c *Repository_GetByID_Call) Return(_a0 resource.Resource, _a1 error) *Repository_GetByID_Call
func (*Repository_GetByID_Call) Run ¶
func (_c *Repository_GetByID_Call) Run(run func(ctx context.Context, id string)) *Repository_GetByID_Call
func (*Repository_GetByID_Call) RunAndReturn ¶
func (_c *Repository_GetByID_Call) RunAndReturn(run func(context.Context, string) (resource.Resource, error)) *Repository_GetByID_Call
type Repository_GetByURN_Call ¶
Repository_GetByURN_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetByURN'
func (*Repository_GetByURN_Call) Return ¶
func (_c *Repository_GetByURN_Call) Return(_a0 resource.Resource, _a1 error) *Repository_GetByURN_Call
func (*Repository_GetByURN_Call) Run ¶
func (_c *Repository_GetByURN_Call) Run(run func(ctx context.Context, urn string)) *Repository_GetByURN_Call
func (*Repository_GetByURN_Call) RunAndReturn ¶
func (_c *Repository_GetByURN_Call) RunAndReturn(run func(context.Context, string) (resource.Resource, error)) *Repository_GetByURN_Call
type Repository_List_Call ¶
Repository_List_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'List'
func (*Repository_List_Call) Return ¶
func (_c *Repository_List_Call) Return(_a0 []resource.Resource, _a1 error) *Repository_List_Call
func (*Repository_List_Call) Run ¶
func (_c *Repository_List_Call) Run(run func(ctx context.Context, flt resource.Filter)) *Repository_List_Call
func (*Repository_List_Call) RunAndReturn ¶
func (_c *Repository_List_Call) RunAndReturn(run func(context.Context, resource.Filter) ([]resource.Resource, error)) *Repository_List_Call
type Repository_Update_Call ¶
Repository_Update_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Update'
func (*Repository_Update_Call) Return ¶
func (_c *Repository_Update_Call) Return(_a0 resource.Resource, _a1 error) *Repository_Update_Call
func (*Repository_Update_Call) Run ¶
func (_c *Repository_Update_Call) Run(run func(ctx context.Context, _a1 resource.Resource)) *Repository_Update_Call
func (*Repository_Update_Call) RunAndReturn ¶
func (_c *Repository_Update_Call) RunAndReturn(run func(context.Context, resource.Resource) (resource.Resource, error)) *Repository_Update_Call